EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Environments_CreateOrUpdateEnvironment',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Environment_Id',
    /* Description_Text        */ 'Creates a new environment, or updates an existing one.'
GO


IF OBJECT_ID('[Environments_CreateOrUpdateEnvironment]') IS NOT NULL DROP PROCEDURE [Environments_CreateOrUpdateEnvironment]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Environments_CreateOrUpdateEnvironment]
(
	@Environment_Name NVARCHAR(50),
    @ServerIds_Csv VARCHAR(MAX),
	@Parent_Environment_Id INT,
    @Environment_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF (@Environment_Id IS NULL)
	BEGIN
		INSERT INTO [Environments] 
		(
			[Environment_Name],
			[Parent_Environment_Id]
		)
		VALUES
		(
			@Environment_Name,
			@Parent_Environment_Id
		)
		SET @Environment_Id = SCOPE_IDENTITY()

		-- EXEC [Events_RaiseEvent] 'ENVNWS', NULL, @Server_Id
	END
	ELSE
	BEGIN
		UPDATE [Environments]
			SET [Environment_Name] = COALESCE(@Environment_Name, [Environment_Name]),
			    [Parent_Environment_Id] = @Parent_Environment_Id
			WHERE [Environment_Id] = @Environment_Id

		--EXEC [Events_RaiseEvent] 'ENVMDS', NULL, @Server_Id
	END

    IF @ServerIds_Csv IS NOT NULL
    BEGIN

        DELETE [EnvironmentServers] WHERE [Environment_Id] = @Environment_Id

        INSERT INTO [EnvironmentServers] ([Environment_Id], [Server_Id])
        SELECT  @Environment_Id,
                CAST([Value_Text] AS INT) FROM dbo.CsvToTable(@ServerIds_Csv, ',')

    END


	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Environments_CreateOrUpdateEnvironment] TO [OtterUser_Role]
