EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Environments_GetEnvironmentsForContext',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Environments_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the union of all environments that are associated with the specified criteria.'
GO

IF OBJECT_ID('[Environments_GetEnvironmentsForContext]') IS NOT NULL DROP PROCEDURE [Environments_GetEnvironmentsForContext]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Environments_GetEnvironmentsForContext]
(
    @Server_Id INT = NULL,
    @ServerRole_Id INT = NULL,
    @Execution_Id INT = NULL,
    @Job_Id INT = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	SELECT E.*
      FROM [Environments_Extended] E
      INNER JOIN [EnvironmentServers] ES
              ON ES.[Environment_Id] = E.[Environment_Id]
       LEFT JOIN [ServerRoleServers] SRS
              ON ES.[Server_Id] = SRS.[Server_Id]
     WHERE ES.[Server_Id] = @Server_Id
        OR SRS.[ServerRole_Id] = @ServerRole_Id 

     UNION

     SELECT E.*
      FROM [Environments_Extended] E
      INNER JOIN [EnvironmentServers] ES
              ON ES.[Environment_Id] = E.[Environment_Id]
      INNER JOIN [Executions] EX
              ON EX.[Server_Id] = ES.[Server_Id]
    WHERE EX.[Execution_Id] = @Execution_Id 

    UNION

     SELECT E.*
      FROM [Environments_Extended] E
      INNER JOIN [JobEnvironments] JE
              ON JE.[Environment_Id] = E.[Environment_Id]
      WHERE JE.[Job_Id] = @Job_Id

END
GO

GRANT EXECUTE ON [Environments_GetEnvironmentsForContext] TO [OtterUser_Role]