EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Jobs_GetServersForExecution',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'Servers_Extended',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the servers that should execute for a Job, based on the job''s associated servers, roles, and environments.'
GO


IF OBJECT_ID('[Jobs_GetServersForExecution]') IS NOT NULL DROP PROCEDURE [Jobs_GetServersForExecution]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Jobs_GetServersForExecution]
(
    @Job_Id INT
)   
AS
BEGIN

    SET NOCOUNT ON

    SELECT * 
      FROM [Servers_Extended]
     WHERE ( NOT EXISTS (SELECT * FROM [JobServers] WHERE [Job_Id] = @Job_Id)
             OR [Server_Id] IN (SELECT [Server_Id] FROM [JobServers] WHERE [Job_Id] = @Job_Id) )
       AND ( NOT EXISTS (SELECT * FROM [JobServerRoles] WHERE [Job_Id] = @Job_Id)
             OR [Server_Id] IN (SELECT [Server_Id] FROM [JobServerRoles] _JR
                                  JOIN [ServerRoles] _SR ON _SR.[ServerRole_Id] = _JR.[ServerRole_Id] 
                                 WHERE [Job_Id] = @Job_Id) )
       AND ( NOT EXISTS (SELECT * FROM [JobEnvironments] WHERE [Job_Id] = @Job_Id)
             OR [Server_Id] IN (SELECT [Server_Id] FROM [JobEnvironments] _JE
                                  JOIN [EnvironmentServers] _ES ON _ES.[Environment_Id] = _JE.[Environment_Id]
                                 WHERE [Job_Id] = @Job_Id) )
     
      
END
GO

GRANT EXECUTE ON [Jobs_GetServersForExecution] TO [OtterUser_Role]