EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Servers_SearchServers',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'DataSet',
    /* DataTableNames_Csv      */ 'Servers_Extended,ServerRoleServers,EnvironmentServers',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets all the servers specified by the filter, as well as their associated environments and roles.'
GO


IF OBJECT_ID('[Servers_SearchServers]') IS NOT NULL DROP PROCEDURE [Servers_SearchServers]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Servers_SearchServers] (
	@Has_ServerRole_Id INT = NULL,
	@In_Environment_Id INT = NULL
)
AS
BEGIN

	SET NOCOUNT ON

	SELECT S.* 
	  INTO #Servers
	  FROM [Servers_Extended] S
	 WHERE (@Has_ServerRole_Id IS NULL OR EXISTS(SELECT * 
                                                   FROM [ServerRoleServers] SR 
                                                  WHERE S.[Server_Id] = SR.[Server_Id] 
                                                    AND SR.[ServerRole_Id] = @Has_ServerRole_Id))
	   
       AND (@In_Environment_Id IS NULL OR EXISTS(SELECT * 
                                                   FROM [EnvironmentServers] ES
                                             CROSS APPLY dbo.Environments_GetAncestorEnvironments(ES.[Environment_Id]) AE
                                                  WHERE S.[Server_Id] = ES.[Server_Id] 
                                                    AND AE.[Environment_Id] = @In_Environment_Id))
	   AND [Active_Indicator] = 'Y'

	SELECT * FROM #Servers
	 ORDER BY [Server_Name] 
	 
	SELECT * FROM [ServerRoleServers] SR 
	 WHERE SR.[Server_Id] IN (SELECT [Server_Id] FROM #Servers)

	SELECT * FROM [EnvironmentServers] ES 
	 WHERE ES.[Server_Id] IN (SELECT [Server_Id] FROM #Servers)

END
GO

GRANT EXECUTE ON [Servers_SearchServers] TO [OtterUser_Role]

